phaseOneCurrentValue property
phaseOneCurrentValue represents the current value for the first phase. It must have positive value.
Implementation
final double phaseOneCurrentValue;
phaseOneCurrentValue represents the current value for the first phase. It must have positive value.
final double phaseOneCurrentValue;