phaseOneVoltageValue property
phaseOneVoltageValue represents the voltage value for the first phase. It must have positive value.
Implementation
final double phaseOneVoltageValue;
phaseOneVoltageValue represents the voltage value for the first phase. It must have positive value.
final double phaseOneVoltageValue;