phaseThreeCurrentValue property
phaseThreeCurrentValue represents the current value for the third phase. It must have positive value.
Implementation
final double phaseThreeCurrentValue;
phaseThreeCurrentValue represents the current value for the third phase. It must have positive value.
final double phaseThreeCurrentValue;