phaseThreeVoltageValue property
phaseThreeVoltageValue represents the voltage value for the third phase. It must have positive value.
Implementation
final double phaseThreeVoltageValue;
phaseThreeVoltageValue represents the voltage value for the third phase. It must have positive value.
final double phaseThreeVoltageValue;