phaseTwoCurrentValue property
phaseTwoCurrentValue represents the current value for the second phase. It must have positive value.
Implementation
final double phaseTwoCurrentValue;
phaseTwoCurrentValue represents the current value for the second phase. It must have positive value.
final double phaseTwoCurrentValue;