phaseTwoVoltageValue property
phaseTwoVoltageValue represents the voltage value for the second phase. It must have positive value.
Implementation
final double phaseTwoVoltageValue;
phaseTwoVoltageValue represents the voltage value for the second phase. It must have positive value.
final double phaseTwoVoltageValue;