PhasorDiagram class
PhasorDiagram widget paints a phasor diagram, graphically representing a three-phase electrical energy system. Each phase has its own voltage and current, and every voltage and current is represented by a value and an angle.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- PhasorDiagram
Constructors
- PhasorDiagram({Key? key, required double size, required double phaseOneVoltageValue, required double phaseOneVoltageAngle, required double phaseTwoVoltageValue, required double phaseTwoVoltageAngle, required double phaseThreeVoltageValue, required double phaseThreeVoltageAngle, required double phaseOneCurrentValue, required double phaseOneCurrentAngle, required double phaseTwoCurrentValue, required double phaseTwoCurrentAngle, required double phaseThreeCurrentValue, required double phaseThreeCurrentAngle})
-
Creates a PhasorDiagram widget to visualize a three-phase electrical
system.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- phaseOneCurrentAngle → double
-
phaseOneCurrentAngle represents the current angle(in degrees) for the
first phase. It must have positive value.
final
- phaseOneCurrentValue → double
-
phaseOneCurrentValue represents the current value for the first phase.
It must have positive value.
final
- phaseOneVoltageAngle → double
-
phaseOneVoltageAngle represents the voltage angle(in degrees) for the
first phase. It must have positive value.
final
- phaseOneVoltageValue → double
-
phaseOneVoltageValue represents the voltage value for the first phase.
It must have positive value.
final
- phaseThreeCurrentAngle → double
-
phaseThreeCurrentAngle represents the current angle(in degrees) for the
third phase. It must have positive value.
final
- phaseThreeCurrentValue → double
-
phaseThreeCurrentValue represents the current value for the third phase.
It must have positive value.
final
- phaseThreeVoltageAngle → double
-
phaseThreeVoltageAngle represents the voltage angle(in degrees) for the
third phase. It must have positive value.
final
- phaseThreeVoltageValue → double
-
phaseThreeVoltageValue represents the voltage value for the third phase.
It must have positive value.
final
- phaseTwoCurrentAngle → double
-
phaseTwoCurrentAngle represents the current angle(in degrees) for the
second phase. It must have positive value.
final
- phaseTwoCurrentValue → double
-
phaseTwoCurrentValue represents the current value for the second phase.
It must have positive value.
final
- phaseTwoVoltageAngle → double
-
phaseTwoVoltageAngle represents the voltage angle(in degrees) for the
second phase. It must have positive value.
final
- phaseTwoVoltageValue → double
-
phaseTwoVoltageValue represents the voltage value for the second phase.
It must have positive value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
size defines the size of the PhasorDiagram widget.
size must be larger than 100.0
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited